


/*
 * slush-xata
 * https://github.com/xanderiel/slush-xata
 *
 * Copyright (c) 2016, Alex Grafe
 * Licensed under the MIT license.
 */





require! {
	"gulp":					gulp
	"gulp-install":			install
	"gulp-conflict":		conflict
	"gulp-template":		template
	"gulp-rename":			rename
	"gulp-util":			gutil
	"underscore.string":	_

	"inquirer":				inquirer
	"path":					path
}

gutil.log "(x) Beginning of slushfile.ls"

format = -> it.to-lower-case!.replace(/\s/g, "")


defaults = do ->
	gutil.log "(0) defaults starts. typeof path = " + typeof path

	workingDirName = path.basename process.cwd!
	gutil.log "(1) workingDirName = " + workingDirName

	if process.platform is "win32"
		homeDir = process.env.USERPROFILE
		osUserName = process.env.USERNAME or path.basename(homeDir).to-lower-case!
		gutil.log "(2) osUserName = " + osUserName
	else
		homeDir = process.env.HOME or process.env.HOMEPATH
		osUserName = homeDir and homeDir.split("/").pop! or "root"

	configFile = path.join(homeDir, ".gitconfig")
	gutil.log "(3) configFile = " + configFile
	user = {}

	if require("fs").exists-sync(configFile)
		user = require("iniparser").parse-sync(configFile).user

	return {
		appName:		workingDirName,
		userName:		osUserName or format(user.name || ""),
		authorName:		user.name or "",
		authorEmail:	user.email or ""
	}




gulp.task "default", (done) ->
	prompts =
		*	message:	"What is the human-readable name of your project?"						name:	"appNameReadable"			default:	defaults.appName
		*	message:	"What is the slugified name of your project?"							name:	"appName"					default:	defaults.appName
		*	message:	"What is the description?"												name:	"appDescription"			default:	"Totally awesome app."
		*	message:	"What is the version of your project?"									name:	"appVersion"				default:	"0.0.1"
		*	message:	"What is the author name?"												name:	"authorName"				default:	defaults.authorName
		*	message:	"What is the author email?"												name:	"authorEmail"				default:	defaults.authorEmail
		*	message:	"What is your github username?"											name:	"githubUserName"			default:	defaults.userName
		*	message:	"Which scope to use on github for this project?"						name:	"githubScope"				default:	defaults.userName

		*	message:	"Are you ready to create the project now?"								name:	"moveon"					type:		"confirm"



	inquirer.prompt prompts, (answers) ->
		if not answers.moveon then done!
		else
			answers.appNameSlug = _.slugify answers.appName

			gulp.src __dirname + "/templates/**"
				.pipe template answers
				.pipe rename (file) ->
					if file.basename[0] is "_" then file.basename = "." + file.basename.slice 1
				.pipe conflict "./"
				.pipe gulp.dest "./"
				.pipe install!
				.on "end", -> done!
